pub enum Event {
Click(MouseButton, MouseButtonState, Point),
MouseMotion(Point),
PositionChange(ComponentPosition),
}Expand description
Event which can be transmitted to the components.
This event needs to be created from the frontend and can then be sent to the bar using
the Bar::notify method. Every component has the choice to use an event or ignore it.
Variants
Click(MouseButton, MouseButtonState, Point)
Mouse button action anywhere on the screen.
This event notifies all components that the user has clicked anywhere on the screen.
It is required that the component knows about its position to act upon this event.
To let a component know about its current position, the PositionChange event
can be used.
MouseMotion(Point)
Update mouse position.
This event notifies all components about the current position of the mouse on the screen.
It is required that the component knows about its position to act upon this event.
To let a component know about its current position, the PositionChange event
can be used.
PositionChange(ComponentPosition)
Update the position of a component.
This event is used to make a component aware of its position on the screen. This is required to react upon other events which are position dependent.